@@ -53,7 +53,7 @@ class Exists(dc.Formula):
     @typechecked
     def contains_variable(self, variable: dc.Variable) -> bool:
         return (
-            any(self.variable == variable)
+            variable in self.variable
             if isinstance(self.variable, set)
             else self.variable == variable
         ) or self.children[0].contains_variable(variable)
