@@ -56,12 +56,12 @@ class Forall(tc.Formula):
     @typechecked
     def expand_quantifiers(self) -> tc.Formula:
         if isinstance(self.variable, set):
-            formula = self.children[0]
+            formula = self.children[0].expand_quantifiers()
             for variable in self.variable:
                 formula = Forall(variable, formula)
             return formula
         else:
-            return self
+            return Forall(self.variable, self.children[0].expand_quantifiers())
 
     @typechecked
     def move_quantifiers_inwards(self) -> tc.Formula:
